title: World Wide Web, Not Wealthy Western Web (Part 2)
url: https://www.smashingmagazine.com/2017/03/world-wide-web-not-wealthy-western-web-part-2/
hash_url: 1b0501a28e2d80b8f8dfa3789903b753

<p>In <a href="https://www.smashingmagazine.com/2017/03/world-wide-web-not-wealthy-western-web-part-1/">part 1</a><sup class="po" id="note-1"><a href="#1">1</a></sup> of this article, we looked at where in the world the new entrants to the World Wide Web are, and some of the new technologies the standards community has worked on to address some of the challenges that the next 4 billion people are facing when accessing the web. In short, we’ve tried to make some supply-side improvements to web standards so that <strong>websites can be made to better serve the whole world</strong>, not just the wealthy West.</p>
<p>But there are other challenges to surmount, such as ways to get over creaky infrastructure in developing markets (which can be done with stopgap technological solutions, such as proxy browsers), and we’ll also look at some of the reasons why some of the offline billions remain offline, and what can be done to address this.</p>
<h3 id="proxybrowers">Proxy Browsers</h3>
<p>A common problem people encounter in emerging economies relates to networks. Networks are getting better, but they’re not there yet. In 2016, <a href="https://www.ericsson.com/thinkingahead/consumerlab/consumer-insights/experience-shapes-mobile-customer-loyalty">Ericsson reported</a><sup class="po" id="note-2"><a href="#2">2</a></sup>:</p>
<blockquote><p>While cellular networks have improved… smartphone users are still facing issues as frequently as they did in 2013. Globally, 26 percent of smartphone users say they face video streaming issues daily, increasing to over one third in markets like Brazil, India and Indonesia.</p></blockquote>
<p>This is an excellent statement of the problem. Infrastructure is expensive to upgrade, especially in countries like Indonesia, which is made up of thousands of islands, and India, which is huge and has vast mountain ranges. And as soon as infrastructure is upgraded, more people come online and want to consume video rather than boring old text, and so much more bandwidth is required, and the newly upgraded network crawls again.</p>
<p>In places where bandwidth is seriously constrained (in congested Asian megacities, not just rural areas; I’m in the heart of an Indian city with an international airport, and power cuts and Internet outages occur daily), a lot of people opt to use proxy browsers. Proxy browsers do a lot of the heavy lifting of rendering web pages on their servers and sending compressed versions down to the user, resulting in often significant reductions in data consumption. This is obviously a very appealing proposition for consumers in territories where bandwidth is expensive. Because the data transferred is smaller, websites render faster, too.</p>
<p><a href="http://data.wurfl.io/MOVR/pdf/2016_q1/MOVR_2016_q1.pdf">Scientia Mobile reported</a><sup class="po" id="note-3"><a href="#3">3</a></sup> in 2016 that, for global market share of proxy browsers, Opera Mini is at 42%, Opera Turbo is at 9%, Chrome is at 39% and UCWeb is at 6%, and there is also Puffin, Silk and others. Opera reports more than 250 million active monthly users of Opera Mini.</p>
<p>Websites compressed by proxy browsers and sent as binary blobs also have a better chance of getting through congested networks. In 2013, Avendus reported (in “India’s Mobile Internet: The Revolution Has Begun,” no longer online):</p>
<blockquote><p>In India, only 96k of the 736k cell towers are 3G enabled… only 35k of those towers have a fiber-optic connection to the backbone.</p></blockquote>
<p>(If you’re a real networking anorak, you’ll find the report <a href="https://docs.google.com/presentation/d/1fZ7ftsJJ4adiPov4y_8AtV_zjqAmEASaSxRBHBwkiOw/edit#slide=id.g73cf3c208_0_158">2G Network Issues Observed While in India</a><sup class="po" id="note-4"><a href="#4">4</a></sup> to be even more fun than a game of Werewolf at a Star Wars convention.)</p>
<h4 id="limitationsofproxybrowsers">Limitations of Proxy Browsers</h4>
<p>So, if proxy browsers are so great, why doesn’t everyone use them? The answer is that such compression comes at a cost; websites can look very different in a proxy browser, and JavaScript can often behave unexpectedly.</p>
<p>In a proxy browser, everything happens on the server, everything needs user interaction, and everything needs a round-trip to the server. Opera Mini on Android and iOS has two modes; one uses proprietary compression techniques and the device’s standard web view, and thus JavaScript isn’t affected. In Opera Mini’s extreme mode, all of the rendering is done on Opera’s server farms, on which JavaScript is allowed to run for 5 seconds and then is throttled. (Disclosure: I was Deputy CTO of Opera until November 2016 and can talk authoritatively about its technology. However, I have no relationship with the company now.)</p>
<p>Therefore, to make websites work in Opera Mini’s extreme mode, treat JavaScript as an enhancement, and ensure that your core functionality works without it. Of course, it will probably be clunkier without scripts, but if your website works and your competitors’ don’t work for Opera Mini’s quarter of a billion users, you’ll get the business.</p>
<p>Mini’s extreme mode has design constraints, too: it doesn’t do CSS rounded corners or gradients, because it can’t rely upon every client device to draw those things successfully; so, to render it on the server, it would need to convert them into bitmaps, which would bloat the page. But that’s OK; CSS is for design, and people in highly bandwidth-constrained situations are happy to get the words.</p>
<p>Similarly, Mini’s extreme mode doesn’t do CSS or SVG animations, only showing the first frame. The reason for this is that animations consume CPU cycles, and CPU cycles consume battery. Yes, your animations are lovely, but if you are sitting on a bus in Lagos in a traffic jam and need to phone your sister to ask her to pick up your children from school, you need that battery life more than you need pretty animations.</p>
<p>Neither does Mini’s extreme mode download web fonts, which can be huge files that are primarily for aesthetics. On many very small monochrome screens, the system fonts tend to be designed for those screens and work better. If you want icons, use SVG rather than icon fonts because, well, that’s what SVG is for.</p>
<h3 id="revolutionarynewdevelopmenttechnique">Revolutionary New Development Technique</h3>
<p>The best way to ensure that your website or web app (is there a real difference?) will work for people on proxy browsers, conventional browsers with very slow connections and everyone else is to adopt a revolutionary new development methodology.</p>
<p>Airbnb tried it with its new app and <a href="http://nerds.airbnb.com/weve-launched-our-first-nodejs-app-to-product/">wrote excitedly</a><sup class="po" id="note-5"><a href="#5">5</a></sup>:</p>
<blockquote><p>… we’ve launched our first Holy Grail app… It looks exactly the same as the app it replaced, however initial pageload feels drastically quicker…</p></blockquote>
<p>What voodoo magic did they employ?</p>
<blockquote><p>… we serve up real HTML instead of waiting for the client to download JavaScript before rendering. Plus, it is fully crawlable by search engines.… It feels 5x faster.</p></blockquote>
<p>Who knew? The best way to ensure that everyone gets your content is to write real, semantic HTML, to style it with CSS and ensure sensible fallbacks for CSS gradients, to use SVG for icons, and to treat JavaScript as an enhancement, ensuring that core functionality works without scripts. Package up your website with a manifest file and associated icons, add a service worker, and you’ll have a progressive web app in conforming browsers and a normal website everywhere else.</p>
<p>I call this amazing new technique “progressive enhancement.”</p>
<p>You heard it here first, folks!</p>
<section>
<p class="oa_zone--ad icad" id="cad-middle" data-ad-name="Content Ad Middle" data-ad-zone="110" data-ad-media="all"/>
</section>
<h3 id="whatifwegaveapartyandnobodycame">What If We Threw A Party And Nobody Came?</h3>
<p>We have supply-side improvements such as HTML responsive images, progressive web apps, renewed CSS work on vertical text. We have the methodology of progressive enhancement. We have proxy browsers that compress websites for people in low-bandwidth and expensive data plans. We have an explosion of ever-cheaper smartphones (and I’m not talking about the Galaxy Note 7 here). So, why aren’t the next 4 billion already on the web?</p>
<p>There are demand-side problems in emerging markets.</p>
<p>One of those is that the market for smartphones is either <a href="http://www.mobileworldlive.com">flat</a><sup class="po" id="note-6"><a href="#6">6</a></sup> or <a href="https://www.strategyanalytics.com/strategy-analytics/blogs/devices/smartphones/smart-phones/2016/04/28/global-smartphone-shipments-decline-3-percent-in-q1-2016#.VyIu60GNL-Q">declining</a><sup class="po" id="note-7"><a href="#7">7</a></sup>, depending on which statistics you read. There are many potential reasons for this: the slowdown in the Chinese economy (China, India and the US are the <a href="http://businesskorea.co.kr/article/10453/poor-performance-samsung-phones-struggling-india-china">largest consumers of smartphones</a><sup class="po" id="note-8"><a href="#8">8</a></sup>); it could be a classic case of market saturation — everyone who wants a smartphone and can afford one already has one.</p>
<p>It could also have to do with devices like the one shown below, which was given to me at the Mobile World Congress SynergyFest.</p>
<figure><a href="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img2-lawson-large-opt.png"><img src="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img2-lawson-800w-opt.png" alt="$2.36 feature phone"/></a><sup class="po" id="note-9"><a href="#9">9</a></sup><br/>
<figcaption>$2.36 feature phone (photo by the author) (<a href="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img2-lawson-large-opt.png">View large version</a><sup class="po" id="note-10"><a href="#10">10</a></sup>)</figcaption>
</figure>
<p>It’s a feature phone, made in China; it doesn’t have Wi-Fi but is dual-SIM (very important in places like Africa and Asia); it has an FM radio; and it can connect to the web with a WAP-like browser. Its retail price in Africa and Latin America is $2.36 USD.</p>
<p>In a country like Cambodia, where a garment worker’s <a href="https://business-humanrights.org/en/cambodia-2015-minimum-wage-negotiations">minimum wage is $140</a><sup class="po" id="note-11"><a href="#11">11</a></sup> a month, or Liberia, where an unskilled worker’s <a href="http://www.liberianobserver.com/politics/passed-minimum-wage-set-us6day">minimum wage is $4</a><sup class="po" id="note-12"><a href="#12">12</a></sup> a day, even a $60 to $70 entry-level smartphone is practically unaffordable. But $2.36? That’s affordable.</p>
<p>But it is not just affordability that stops people from coming to the web. As <a href="https://www.gsmaintelligence.com/research/2016/07/consumer-barriers-to-mobile-internet-adoption-in-africa/568/">GSMA Intelligence wrote</a><sup class="po" id="note-13"><a href="#13">13</a></sup> in July 2016:</p>
<blockquote><p>Despite the fact that Africa has the lowest income per capita of any region, affordability was only identified as the most important barrier in one out of 13 markets in our survey.</p></blockquote>
<p>And it’s not just about networks either, as <a href="https://www.gsmaintelligence.com/research/2016/07/consumer-barriers-to-mobile-internet-adoption-in-africa/568/">GSMA Intelligence reports</a><sup class="po" id="note-14"><a href="#14">14</a></sup>:</p>
<blockquote><p>Network coverage was not perceived as an issue in most countries, reflecting the increasing availability of mobile networks. However, mobile broadband (3G or 4G) coverage remains low in most parts of Africa.</p></blockquote>
<p>The problem is much more profound, and doesn’t have a technological solution. From the same report:</p>
<blockquote><p>A lack of awareness and locally relevant content was considered the most important barrier to internet adoption in North Africa and the second biggest barrier in Sub-Saharan Africa.</p></blockquote>
<p>There’s also a worrying lack of digital skills that prevents people from using the web in Africa:</p>
<blockquote><p>A lack of digital skills was identified as the biggest barrier to internet adoption in Sub-saharan Africa and the second biggest in North Africa.</p></blockquote>
<p>The <a href="http://www.worldbank.org/en/publication/wdr2016">World Bank reports</a><sup class="po" id="note-15"><a href="#15">15</a></sup>:</p>
<blockquote><p>In Africa, seven in ten people who do not use the internet say they just don’t know how to use it, and almost four in ten say they do not know what the internet is.</p></blockquote>
<p>This is true not only of developing economies, by the way. The World Bank continues:</p>
<blockquote><p>In high-income Poland and the Slovak Republic, one-fifth of adults cannot use a computer.</p></blockquote>
<p>And in 2014, <a href="http://www.pewinternet.org/2014/04/03/older-adults-and-technology-use/">Pew Research Centre reported</a><sup class="po" id="note-16"><a href="#16">16</a></sup>:</p>
<blockquote><p>41% [of American seniors] do not use the internet at all, 53% do not have broadband access at home, and 23% do not use cell phones.</p></blockquote>
<p>The lack of digital skills is felt acutely by Asia, too. In its January 2016 <a href="https://www.gsmaintelligence.com/research/2016/06/consumer-barriers-to-mobile-internet-adoption-in-asia/559/">Asia survey</a><sup class="po" id="note-17"><a href="#17">17</a></sup>, GSMA Intelligence wrote:</p>
<blockquote><p>A lack of awareness and locally relevant content was the most commonly cited barrier to internet adoption: 72% of non-internet users across the six survey markets felt this was a barrier.… 50% of websites worldwide are in English, a language spoken by only 10% of speakers in the survey countries. By way of contrast, only 2% of websites worldwide are in Mandarin and less than 0.1% are in Hindi.</p></blockquote>
<p>Below is a video made in a user-testing lab in rural Pakistan, featuring a man in his 20s. He has used a feature phone but never a smartphone. He’s given a simple-sounding task: Go to Google and search for the the name of your favourite actress. Watch the video. Watch it all.</p>
<p/>
<p>Presumably, he’s stuck because he’s been accustomed to a feature phone with physical keys, and he simply doesn’t know how to call up the virtual keyboard. Anytime you believe that doing something in your web app is “obvious” or “intuitive”, watch this video again.</p>
<h4 id="digitaldivide">Digital Divide</h4>
<p>Just as there is a digital divide between “the West” and developing economies, there is a digital divide in income, age, rural and urban, and women and men across the developing world. The World Bank illustrates a divide in income, gender, age and location (rural and urban).</p>
<figure><a href="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img3-lawson-large-opt.png"><img src="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img3-lawson-800w-opt.png" alt="Digital divide in Africa"/></a><sup class="po" id="note-18"><a href="#18">18</a></sup><br/>
<figcaption>Digital divide in Africa (World Bank figures) (<a href="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img3-lawson-large-opt.png">View large version</a><sup class="po" id="note-19"><a href="#19">19</a></sup>)</figcaption>
</figure>
<p>In February 2016, <a href="http://www.gadgetsnow.com/tech-news/Only-9-of-rural-India-has-access-to-mobile-internet-Report/articleshow/50840296.cms">53% of urban areas</a><sup class="po" id="note-20"><a href="#20">20</a></sup> had mobile Internet connectivity, a growth of 71% in one year. In the same period, Internet usage in rural India increased by 93%, but that means that only 9% of people in rural India has access. As I write this, there is a copy of The Hindu newspaper next to my laptop, which <a href="http://www.thehindu.com/business/Wi-fi-hotspots-coming-soon-to-a-store-near-you/article17264038.ece">today reports</a><sup class="po" id="note-21"><a href="#21">21</a></sup> that the Indian government is recommending a community model of Wi-Fi hotspots, such as in neighborhood grocery stores, in rural areas where connectivity is poor and laying cables is not feasible.</p>
<p>The World Bank reports that in many countries (Cuba, Cambodia, Brazil and others), computers are taxed as luxury goods.</p>
<figure><a href="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img4-lawson-large-opt.png"><img src="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img4-lawson-800w-opt.png" alt="Computers and laptops: import tariffs"/></a><sup class="po" id="note-22"><a href="#22">22</a></sup><br/>
<figcaption>Computers and laptops: import tariffs (World Bank figures) (<a href="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img4-lawson-large-opt.png">View large version</a><sup class="po" id="note-23"><a href="#23">23</a></sup>)</figcaption>
</figure>
<p>Many countries, such as Fiji, Bangladesh and Pakistan, tax mobile phones as luxuries, too.</p>
<figure><a href="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img5-lawson-large-opt.png"><img src="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img5-lawson-800w-opt.png" alt="Mobile phones: import tariffs"/></a><sup class="po" id="note-24"><a href="#24">24</a></sup><br/>
<figcaption>Mobile phones: import tariffs (World Bank figures) (<a href="https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img5-lawson-large-opt.png">View large version</a><sup class="po" id="note-25"><a href="#25">25</a></sup>)</figcaption>
</figure>
<h3 id="pressureforchange">Pressure For Change</h3>
<p>The World Bank recommends that:</p>
<blockquote><p>Making the internet universally accessible and affordable should be a global priority.</p></blockquote>
<p>There are moves afoot to make this happen, such as an initiative called <a href="https://webwewant.org/fast-africa/">FASTAfrica</a><sup class="po" id="note-26"><a href="#26">26</a></sup>. FAST stands for fast, affordable, secure and transparent. In a series of grassroots events across Africa in 2016, the organization has demanded:</p>
<ul>
<li>fair and transparent taxes on information and communications technology (ICT),</li>
<li>greater effort from governments and donors,</li>
<li>agreement on affordability (1 GB for 2% of disposable income),</li>
<li>prioritization of getting women online.</li>
</ul>
<h4 id="worldwidewebwomen">World Wide Web Women</h4>
<p>The World Bank writes:</p>
<blockquote><p>Online work can prove particularly beneficial for women, youth, older workers, and the disabled, who may prefer the flexibility of working from home or working flexible hours.</p></blockquote>
<p><a href="https://www.gsmaintelligence.com/research/2016/07/consumer-barriers-to-mobile-internet-adoption-in-africa/568/">GSMA Intelligence writes</a><sup class="po" id="note-27"><a href="#27">27</a></sup>:</p>
<blockquote><p>In India… women are 62% less likely to use the internet than men. Many of the underlying reasons for this — affordability, skills and content — are the same as for men; they are simply felt more acutely by women.</p></blockquote>
<p>In rural India, only <a href="https://www.bcgperspectives.com/content/articles/globalization-customer-insight-rising-connected-consumer-rural-india/">2% of web users are women</a><sup class="po" id="note-28"><a href="#28">28</a></sup>.</p>
<p>Yet we know that the web empowers women. Across the world in non-agricultural employment, women make up 25% of the work force, but in online work, women make up 44% of the work force.</p>
<p>When asked why online work is advantageous, women overwhelmingly cited the ability to work flexible hours from home as the primary advantage. (32% of women, compared with 23% of men, said that the primary disadvantage to online work is that payment is not high enough, which suggests that Africa, too, has an unjustifiable difference between what women and men get paid.</p>
<p>One successful government initiative is the <a href="http://www.kudumbashree.org/">Kudumbashree project</a><sup class="po" id="note-29"><a href="#29">29</a></sup>, here in Kerala, India, where I’m writing this. “Kudumbashree” means “prosperity of the family” in the local Malayalm language. The World Bank reports:</p>
<blockquote><p>The government of Kerala, India, outsources information technology services to cooperatives of women from poor families … Average earnings were US$45 a month, with close to 80 per-cent of women earning at least US$1 a day. Nine in ten of the women had previously not worked outside the home. Samasource, RuralShores, and Digital Divide Data are three private service providers. Samasource splits jobs into microwork for almost 6,400 workers, mostly in Ghana, Haiti, India, Kenya, and Uganda, on average more than doubling their previous income.</p></blockquote>
<p>A similar story is happening in China:</p>
<blockquote><p>Online shop owners using Alibaba in China, on average, employ 2.6 additional workers. Four in ten shop owners are women, 19 percent were previously unemployed, 7 percent were farmers, and about 1 percent are persons with disabilities.</p></blockquote>
<h3 id="whatcanbedoneandhowcanyouhelp">What Can Be Done, And How Can You Help?</h3>
<p>The World Bank says that:</p>
<blockquote><p>Access to the internet is critical, but not sufficient. The full benefits of the information and communication transformation will not be realized unless countries continue to improve their business climate, invest in people’s education and health and promote good governance</p></blockquote>
<p>Should you happen to be a politician in Africa, Asia or Latin America, please take note of the above. But, because you’re reading this, I expect you’re a web professional — but you can play your part! Make sure your websites are ready for the next 4 billion people, with their (potentially) slow networks and browsers and devices you may never have heard of.</p>
<ul>
<li>Progressively enhance to make sure your core functionality works without JavaScript.</li>
<li>Use feature detection, rather than browser sniffing. You will never, ever be able to maintain a list of all devices in the world and their UA strings.</li>
<li>Compress images properly and remove unnecessary meta data with a tool such as <a href="https://imageoptim.com/">ImageOptim</a><sup class="po" id="note-30"><a href="#30">30</a></sup>.</li>
<li>Use HTML responsive images (and generate <a href="https://www.smashingmagazine.com/2015/10/webp-images-and-performance/">WebP</a><sup class="po" id="note-31"><a href="#31">31</a></sup> versions of all of your assets), and send them to supporting browsers with the <code>picture</code> element.</li>
<li>Focus relentlessly on performance.</li>
<li>Write a progressive web app, rather than a native app.</li>
<li>Test in a proxy browser, such as Opera Mini.</li>
</ul>
<p>Developing countries are home to 94% of the global offline population. These people may be your next potential customers. But if they can’t buy from you because your website is a Wealthy Western Website rather than a World Wide Website, you can bet that your competitors will be happy to take their money.</p>
<p><a href="http://www.mckinsey.com/industries/high-tech/our-insights/internet-matters">McKinsey Global Institute writes</a><sup class="po" id="note-32"><a href="#32">32</a></sup>:</p>
<blockquote><p>An increase in internet maturity similar to the one experienced in mature countries over the past 5 years creates an increase in real GDP per capita of $500 on average during this period. It took the industrial revolution of the 19th century 50 years to produce same result.</p></blockquote>
<p>But it’s not just about money. It’s about doing the right thing and keeping the web open, democratic and global.</p>
<p>Millions of people in Bangladesh, Nepal and India have miles to walk to visit a doctor, so a feature phone and the free online book <a href="http://hesperian.org/books-and-resources/"><em>Where There Is No Doctor</em></a><sup class="po" id="note-33"><a href="#33">33</a></sup> (often translated to their local language) becomes first-line medical care.</p>
<p>Millions of people in Subsaharan Africa can’t afford school textbooks, but <a href="https://www.worldreader.org/what-we-do/our-books/">Worldreader</a><sup class="po" id="note-34"><a href="#34">34</a></sup> has tens of thousands of books available for free online, and the books work fine even on old feature phones.</p>
<p>And millions of people in despotic regimes have the web as their only way to contact the outside world.</p>
<p>Please, do your part to ensure the health of the web that has provided you with so much, and pay it forward so the next people can benefit.</p>
<hr/>
<p><em>Thanks to <a href="https://mrunmaiy.com/">Mrunmaiy Abroal</a><sup class="po" id="note-35"><a href="#35">35</a></sup>, until recently Opera’s Head of Comms in India, and <a href="https://twitter.com/peko0413">Peko Wan</a><sup class="po" id="note-36"><a href="#36">36</a></sup>, Head of PR &amp; Communications for Opera in Asia, for their help collecting some of the information in this article. Thanks to <a href="https://twitter.com/kgisdahl">Karin Greve-Isdahl</a><sup class="po" id="note-37"><a href="#37">37</a></sup>, VP Communications at Opera for allowing me to use charts and illustrations made while I was at Opera. Big thanks to Clara at <a href="http://www.damcho.com">Damcho Studio</a><sup class="po" id="note-38"><a href="#38">38</a></sup> for helping to prepare this article.</em></p>
<p><em property="editor">(vf, al, il)</em></p>
<ol class="po"><li id="#1"><a href="#note-1">1 https://www.smashingmagazine.com/2017/03/world-wide-web-not-wealthy-western-web-part-1/</a></li><li id="#2"><a href="#note-2">2 https://www.ericsson.com/thinkingahead/consumerlab/consumer-insights/experience-shapes-mobile-customer-loyalty</a></li><li id="#3"><a href="#note-3">3 http://data.wurfl.io/MOVR/pdf/2016_q1/MOVR_2016_q1.pdf</a></li><li id="#4"><a href="#note-4">4 https://docs.google.com/presentation/d/1fZ7ftsJJ4adiPov4y_8AtV_zjqAmEASaSxRBHBwkiOw/edit#slide=id.g73cf3c208_0_158</a></li><li id="#5"><a href="#note-5">5 http://nerds.airbnb.com/weve-launched-our-first-nodejs-app-to-product/</a></li><li id="#6"><a href="#note-6">6 http://www.mobileworldlive.com</a></li><li id="#7"><a href="#note-7">7 https://www.strategyanalytics.com/strategy-analytics/blogs/devices/smartphones/smart-phones/2016/04/28/global-smartphone-shipments-decline-3-percent-in-q1-2016#.VyIu60GNL-Q</a></li><li id="#8"><a href="#note-8">8 http://businesskorea.co.kr/article/10453/poor-performance-samsung-phones-struggling-india-china</a></li><li id="#9"><a href="#note-9">9 https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img2-lawson-large-opt.png</a></li><li id="#10"><a href="#note-10">10 https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img2-lawson-large-opt.png</a></li><li id="#11"><a href="#note-11">11 https://business-humanrights.org/en/cambodia-2015-minimum-wage-negotiations</a></li><li id="#12"><a href="#note-12">12 http://www.liberianobserver.com/politics/passed-minimum-wage-set-us6day</a></li><li id="#13"><a href="#note-13">13 https://www.gsmaintelligence.com/research/2016/07/consumer-barriers-to-mobile-internet-adoption-in-africa/568/</a></li><li id="#14"><a href="#note-14">14 https://www.gsmaintelligence.com/research/2016/07/consumer-barriers-to-mobile-internet-adoption-in-africa/568/</a></li><li id="#15"><a href="#note-15">15 http://www.worldbank.org/en/publication/wdr2016</a></li><li id="#16"><a href="#note-16">16 http://www.pewinternet.org/2014/04/03/older-adults-and-technology-use/</a></li><li id="#17"><a href="#note-17">17 https://www.gsmaintelligence.com/research/2016/06/consumer-barriers-to-mobile-internet-adoption-in-asia/559/</a></li><li id="#18"><a href="#note-18">18 https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img3-lawson-large-opt.png</a></li><li id="#19"><a href="#note-19">19 https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img3-lawson-large-opt.png</a></li><li id="#20"><a href="#note-20">20 http://www.gadgetsnow.com/tech-news/Only-9-of-rural-India-has-access-to-mobile-internet-Report/articleshow/50840296.cms</a></li><li id="#21"><a href="#note-21">21 http://www.thehindu.com/business/Wi-fi-hotspots-coming-soon-to-a-store-near-you/article17264038.ece</a></li><li id="#22"><a href="#note-22">22 https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img4-lawson-large-opt.png</a></li><li id="#23"><a href="#note-23">23 https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img4-lawson-large-opt.png</a></li><li id="#24"><a href="#note-24">24 https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img5-lawson-large-opt.png</a></li><li id="#25"><a href="#note-25">25 https://www.smashingmagazine.com/wp-content/uploads/2017/02/pt2-www-img5-lawson-large-opt.png</a></li><li id="#26"><a href="#note-26">26 https://webwewant.org/fast-africa/</a></li><li id="#27"><a href="#note-27">27 https://www.gsmaintelligence.com/research/2016/07/consumer-barriers-to-mobile-internet-adoption-in-africa/568/</a></li><li id="#28"><a href="#note-28">28 https://www.bcgperspectives.com/content/articles/globalization-customer-insight-rising-connected-consumer-rural-india/</a></li><li id="#29"><a href="#note-29">29 http://www.kudumbashree.org/</a></li><li id="#30"><a href="#note-30">30 https://imageoptim.com/</a></li><li id="#31"><a href="#note-31">31 https://www.smashingmagazine.com/2015/10/webp-images-and-performance/</a></li><li id="#32"><a href="#note-32">32 http://www.mckinsey.com/industries/high-tech/our-insights/internet-matters</a></li><li id="#33"><a href="#note-33">33 http://hesperian.org/books-and-resources/</a></li><li id="#34"><a href="#note-34">34 https://www.worldreader.org/what-we-do/our-books/</a></li><li id="#35"><a href="#note-35">35 https://mrunmaiy.com/</a></li><li id="#36"><a href="#note-36">36 https://twitter.com/peko0413</a></li><li id="#37"><a href="#note-37">37 https://twitter.com/kgisdahl</a></li><li id="#38"><a href="#note-38">38 http://www.damcho.com</a></li></ol>
