title: Why is CSS Frustrating?
url: https://css-tricks.com/why-is-css-frustrating/
hash_url: afb9fa99e3c43324fbe57b416562b8f9

<p>Here’s <a href="https://twitter.com/KevinJPowell/status/1231979370446802945">a great thread</a> by Kevin Powell that's making the rounds. He believes so many folks see CSS as a frustrating and annoying language:</p>

<blockquote class="twitter-tweet" data-width="500" data-dnt="true"><p lang="en" dir="ltr">That&#39;s just as unintuitive as JS starting to count at 0, but since you learned that and accept it, it&#39;s fine.<br><br>The real issue isn&#39;t with CSS. If you struggle with it, or ever call it unintuitive, it&#39;s probably because you don&#39;t really understand how CSS is meant to work.</p>&mdash; Kevin Powell (@KevinJPowell) <a href="https://twitter.com/KevinJPowell/status/1231979376830484481?ref_src=twsrc%5Etfw">February 24, 2020</a></blockquote>

<p>Why do people respect JavaScript or other languages enough to learn them inside-out, and yet constantly dunk on CSS? Well, all this reminds me of what Jeremy Keith wrote a while back when he argued that <a href="https://adactio.com/journal/12571">CSS is simple, but not easy</a>:</p>
<blockquote class="wp-block-quote"><p>Unlike a programming language that requires knowledge of loops, variables, and other concepts, CSS is pretty easy to pick up. Maybe it’s because of this that it has gained the reputation of being simple. It <em>is</em> simple in the sense of “not complex”, but that doesn’t mean it’s easy. Mistaking “simple” for “easy” will only lead to heartache.</p><p>I think that’s what’s happened with some programmers coming to CSS for the first time. They’ve heard it’s simple, so they assume it’s easy. But then when they try to use it, it doesn’t work. It must be the fault of the language, because they know that they are smart, and this is supposed to be easy. So they blame the language. They say it’s broken. And so they try to “fix” it by making it conform to a more programmatic way of thinking.</p></blockquote>
<p>There have been time where I’ve sat down with engineers to pair with them about a tricky layout issue and the CSS is treated as being beneath them — as if the language is somehow too unpredictable to warrant learning and mastering. Perhaps this has something to do with the past, where we’ve spent years fighting the way browsers render things differently. But this is mostly a solved problem. I can’t remember the last time I fought against browsers like that.</p>
<p>Instead, I reckon the biggest issue that engineers face — and the reason why they find it all so dang frustrating — is that CSS forces you to face the <em>webishness</em> of the web. Things require fallbacks. You need to take different devices into consideration, and all the different ways of seeing a website: mobile, desktop, no mouse, no keyboard, etc. Sure, you have to deal with that when writing JavaScript, too, but it’s easier to ignore. You can’t ignore the layout of your site being completely broken on a phone.</p>
<p><strong>Side note:</strong> We have <a href="https://css-tricks.com/centering-css-complete-guide/">a guide to centering in CSS</a> not because CSS is busted and dumb, but because there are so many variables to the extent that a simple question like, “How do I center text?” is actually much more complicated than it appears. There’s so much context that’s missed.</p>
<p>This reminds me of one of my favorite blog posts of all time, where Brandon Smith argues that <a href="https://css-tricks.com/css-is-awesome/">CSS is awesome</a> and we should respect the language and learn how it works under the hood:</p>
<blockquote class="wp-block-quote"><p>CSS is hard because its properties interact, often in unexpected ways. Because when you set one of them, you're never just setting that one thing. That one thing combines and bounces off of and contradicts with a dozen other things, including default things that you never actually set yourself.</p><p>One rule of thumb for mitigating this is, <strong>never be more explicit than you need to be</strong>. Web pages are responsive by default. Writing good CSS means leveraging that fact instead of overriding it. Use percentages or viewport units instead of a media query if possible. Use <code>min-width</code> instead of <code>width</code> where you can. Think in terms of rules, in terms of <em>what you really mean to say</em>, instead of just adding properties until things look right. Try to get a feel for how the browser resolves layout and sizing, and make your changes and additions on top of that judiciously. Work with CSS, instead of against it.</p></blockquote>
