title: The world needs a tech diet; here is how designers can help
url: https://essays.uxdesign.cc/tech-diet/
hash_url: 3159c32fa194458a63b546ab789e8aed

If you use digital products on a daily basis, you’ve probably noticed the proliferation of dark design patterns that try to manipulate you to engage further, deeper, or longer on a website or app.

We are not in control of our tools anymore

It’s time we bridge the gap between feel-good Design & Ethics panels and the work we do every day as digital product designers.

Image: David Teodorescu

 

UI copy that fabricates a sense of scarcity, urging you to book a hotel room before someone else does. Confirm-shame links that try to bully users into entering their email addresses. Streaming platforms that autoplay new episodes, encouraging binge-watching behavior. 

 

Eager for clicks and views, tech platforms are always looking for new ways to use basic human instincts like shame, laziness and fear to their advantage. Digital junk foods, from social networking apps to video streaming platforms, promise users short-term highs but leave depressive existential lulls in their wake. 

 

The result? Our relationship with technology is becoming increasingly characterized by dependency, regret, and loss of control.

 

 

 

 

 

But wait...

 

How did we get here?

 

While the products we build every day have evolved, our ways of thinking about user engagement have scarcely changed since the days of dial-up. We assume that the higher the metrics, the more successful the business and, thus, the smarter the product designer.

 

Clicks

Views

Session duration

Shares

Sign-ups

Response rate

Avg time on page

Pages per visit

Dormancy rate

Leads generated

Opens per week

Bounce rate

And we’ve become so good at engagement over the years, we have approached its pursuit as a science. We have deified products like Instagram or Tinder for their shamelessly addictive qualities. We have learned and taught each other how to design for addiction, always devising new ways to keep people coming back for more. 

But in some cases, we are simply defining metrics out of apathy. We forget to question the real business value behind each of those KPIs. After all, more page views per visit to an e-commerce website do not necessarily mean more sales. Likewise, the number of opens per week for a mobile banking app tells us little about customer loyalty and satisfaction — when it comes to their financial life, aren’t people looking for peace of mind instead?

 

 

Over the past few decades, we have helped build a corporate culture that systematically prioritizes short-term gains over longer-term product health.

 

The introduction of digital products and services into our lives has substantially changed the way our relationship to time, effort, and initiative. We might not think about this all the time, but we are not as in control of those digital tools as we are of the physical ones around us.

 

 

A tool such as a chainsaw has to be manually initiated by its user...

 

...that’s not the case with digital tools like phones, which are often initiating interactions with us.

 

When you look (or think of) a mug, you know pretty accurately how much effort it will take to lift it up...

 

...that’s not the case when you click on a “Get Started” button on an insurance provider website.

 

When you look at a tube and compare it to the size of your saw, you can estimate how much time it will take you to complete the task...

 

...that’s not the case with the endless feeds we are exposed to in social media apps and blogs.

 

“

 

Although the digital revolution has pushed technology forward, it has also left people with no choice but to conform to the new rules and paradigms set by this technology.
— Marigo Heijboer

The new digital tools of our era don’t have natural affordances unless the designer consciously decides to design them in a transparent, honest way.

 

 

Turns out... 

Times, 
they are 
a-changing

 

 

01

Discussions around our unhealthy relationship with technology are becoming mainstream.

 

 

Politicians starting to create laws against dark patterns

Tech companies drowned in scandals about privacy and user data

Mass media outlets started covering tech issues more frequently

02

Companies observing this trend are starting to act — but in timid ways.

 

 

Instagram lets users know when they finish scrolling through the feed

Youtube, iOS and other mobile OSs let people track and limit how much time they are spending in each app

 

Bumble gives users the option to disconnect, including taking a “digital detox” mode

03

A more minimalist mindset is emerging in our Zeitgeist and our Netflix watchlists.

 

 

 

 

Marie Kondo: the Netflix sensation who teaches American families to prioritize belongings that ‘spark joy’ while purging the stuff they don’t need

Tiny Homes: a show about people choosing to simplify their lives by downsizing their living spaces 

Minimalism: a documentary about those who have rejectedthe American idea that more consumption brings greater happiness

Hey—

enough

talking

 

As designers, how do we actually break the cycle of designing for addictive engagement?

Keep scrolling, keep scrolling

Change has to start somewhere. Seeing a gap between our well-intended ideas and the work we do every day, we have decided to create a more practical guide to provoking change.

 

How can we break the business-as-usual cycle...

 

In our design

In our process

In our company

In our community

In our personal life

 

 

 

 

 

In our design

 

Set solid design principles

Crown Hall, Illinois Institute of Technology, Chicago (1956). Architectural Press Archive / RIBA Collections

Design principles that strive for reduction and simplification have been around for a while. The philosophy at the core of the 20th century Modernist aesthetic movement, for example, lay the idea that the world had to be fundamentally rethought and streamlined, promoting sleek, clean lines and eliminating decorative additions that were purely for the sake of embellishment. 

 

Thirty years ago, Don Norman published The Design of Everyday Things, outlining principles product designers who wanted to create better experiences should follow. Today, in the age of intangible digital products, we need to decide —and stick to— larger principles that will guide our work. 

 

Where to start:

Massimo Vignelli →

Vignelli has made a fundamental contribution to the world of design by keeping alive and promoting the evolution of the ethical principles developed by the Modern Movement in the early 20th century.

 

 

Dieter Rams →

Industrial designer at the helm of the creative direction of the German brand Braun. Rams led one of the most important movements of the industrial design world, known as functionalism.

More recently:

 

 

Ruined by Design →

Inspired by Victor Papanek’s understanding of the relationship between design and politics as well as the current state of the tech industry, this book by Mike Monteiro argues that designers have destroyed the world and offers practical advice on how we can fix it. 

Calm Tech Principles →

Coined in 1995 by PARC Researchers Mark Weiser and John Seely Brown in reaction to the increasing complexities created by information technologies, the “Calm Technology” movement has been led by researcher and author Amber Case.

In our design

 

Choose respectful design patterns

 

“

 

Design reproduces dominant relationships unless there is a deliberate effort to change them.

—Dan Zollman

As designers, we can play a crucial role in the creation of healthier products and services. Ultimately, we are the ones choosing UI patterns, writing copy, and defining flows and interactions. So it’s on us to question whether we are doing our jobs responsibly. The same way tech addiction is created through design, design can also be used to promote a healthier relationship with technology.

 

 

 

 

Stop endless scroll

Instead of designing for infinite engagement, what if we prioritized more relevant content?

Reduce notifications

Not everything is important. What if we rethought our notification strategy to be more mindful of people’s attention and time?

 

Reveal info gradually

What if instead of giving users all information at once, we were more thoughtful about when and how each message is revealed?

Give them control

What if we design user experiences that are more transparent,giving people control over their level of engagement?

 

Further reading:

 

Humane by Design →

Humane by Design is a resource that provides guidance for designing ethically responsible digital products through patterns focused on user well-being.

 

Design for Behavior Change →

Stephen Wendel's book is a practical guide to designing for behavior change, highlighting the importance of mastering behavioral design in order to use them for good.

In our process

 

Run better research

Research helps us better understand our users. However, not all research is equally effective. 

 

 

 

 

 

 

 

 

 

 

Know your tools and when to use them

If not well planned, research can be misleading: a usability test session may show users are able to act quickly on a task, but neglect to ask how this task impacts them and whether they even want to perform it in the first place. Foundational research (such as an ethnographic study), done early and often, can help bring the user perspective to your team and to the product strategy — before you jump into directional studies (like a usability testing).

→

Go wide in your research

Even when planning directional research, use the opportunity to understand broader user behaviors and orientations towards  your product and towards tech more generally. Set up the interview as a conversation and try to learn more about the following: 

• In what context do they use your product? 

• How does the product influence their relationships with others around them? 

• By using your product, what are they giving up? 

• What else can you learn about them that you don't know yet?

→

Be mindful about how you frame questions 

According to Erika Hall, "The big research question is what you want to know, not what you ask in an interview. In fact, asking your research question directly is often the worst way to learn anything.”

 

 

→

In our process

 

Challenge default metrics

 

“

 

Until we measure what we value, we will over-value what we measure.

—Kim Goodwin at IAC19

There are two common scenarios when it comes to metrics:

•

 

The business has a focus on growth metrics and the design work is limited to aggressively improving those numbers; or

 

•

 

The business has not established its own metrics and relies on canned metrics, meaning the design work is disconnected from its  impact on users.

 

Both scenarios can be quite damaging and can lead to designers using dark patterns to hit their goals faster. 

 

Designers need to be part of the metric discussion not only to bring in the user's perspective but to keep in check how a particular metric can influence or be influenced by the whole product ecosystem.

 

For each business metric, the product can have a user-centered metric as well as a counter-metric to keep the bigger picture in play. 

Forget growth hacks

Counter-metrics can help you to avoid both the "get rich quick" scheme mentality of crazy growth metrics as well as the "end justifies the means" philosophy that justifies creating addictive and unhealthy behaviors in users.

 

→

Follow your heart

Google's HEART framework is a great way to start talking about metrics. Remember that your users don't just want to be "happy"; try to be specific about how each goal translates into their personal objectives.

 

→

Measure what you value

If improving people's relationships with tech is something you value, you should measure it — and make people accountable for it.  Quoting Kim Goodwin at the IAC 2019: "until we measure what we value, we will over-value what we measure".

→

In our process

 

Anticipate unhealthy behaviors

 

Imagine this: A young woman joins the LGBTQ choir at her college. Her choir leader adds her to the group’s Facebook page, and Facebook automatically shares this action on the student’s Newsfeed. However, she had not come out to her family yet. When they see the news on Facebook, the extremely religious community from her hometown sends her hate mail. (Mike Monteiro)

 

As designers, we are used to thinking about happy paths, ideal flows, and all the great ways people will engage with our products. But what are some of the ways they can cause unintended harms?

 

Here are some questions you can use to brainstorm on your own or with your team:

 

Depression

Is your product stimulating depressive behaviors, or could your product experience aggravate symptoms of depression? How might a person with depression or someone experiencing suicidal thoughts use your product to hurt themselves?

 

Addiction

Does your product encourage addictive behaviors? What is the worst case scenario for users susceptible to addiction?

 

Exclusion

Is your product accessible to all user groups, regardless of disabilities, culture, education levels, and language? Is it possible that your product could be used to exclude certain groups? Or does your product unwittingly perpetuate cycles of exclusion?

 

Oversharing 

Does your product encourage sharing personal information? What are some of the possible negative outcomes of that overexposure? What emotions can content trigger in other users and what kinds of effects might these emotions have?

 

Abusive relationships

Could someone take advantage of your product or platform to create a relationship of unhealthy dependence or domination with another user (e.g. blackmail, bribery)?

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

How to act:

Brainstorm unintended, unhealthy behaviors

Consider how people could misuse your features and what type of bad behaviors can happen currently and in the future.

 

 

→

 

Dive deeper in user research

How would these behaviors make people feel? Use research not only to test the desired flow but also when your product fails.

 

→

 

Quantify the current state

Include in your metrics and analysis the current state of bad behaviors as well as future risks that it can create.

 

→

 

Seek opportunity for positive impact

Think of ways your company can create a positive impact or educate users around the issue of healthier tech behaviors and then align these objectives with your product goals.

 

→

 

Generate awareness 

Share your work on preventing unhealthy behaviors with your organization to increase awareness and buy-in.

 

→

 

In our organization

 

Convince your 
C-levels

 

“

 

If your business depends on dark patterns to succeed, you’re just leaving yourself open to being disrupted.

—Harry Brignull

 

 

 

The threat of negative press is a powerful incentive for change in organizations — especially when it comes to those actions that depend on top-down decisions from high-up stakeholders. The mere possibility of having to deal with a PR crisis creates fear: no one wants to have their brand associated with crimes, catastrophes, or misuse of user data.

 

 

 

Sometimes mockups speak louder than strategy slides 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

As product designers, we shouldn’t be driving our decisions around negative PR headlines. But if we need to speak C-level language, mocking fake press releases are definitely an effective way to grab executive level attention.

Have a conversation about long-term health

Despite the fact that dark patterns bring short-term gains, experts agree that implementing them in your business is a bad idea. The initial boost in the number of new users rarely results in an increase of loyal customers, as deception tends to erode trust. Show the higher ups examples of companies who have been focusing too much on short-term goals and struggling to maintain their long-term platform health — as well as the initiatives they have started to take to fix that issue.

→

Create actionable fear

Write and mock up fake headlines that shows the bad behaviors that can happen in your platform. Include them in your presentations and pose the question, “What can we do to avoid these issues?” For each problem you bring to colleagues’ attention, make sure to follow up with tangible design principles (or Dos and Don’ts slides) that will help your team avoid worst-case scenarios. 

 

→

Show positive results

Remind your team of past initiatives and design updates your company has made to control bad behavior, and the results you have seen. Building on top of previous efforts will feel less daunting than creating net new initiatives or features.

→

In our organization

 

Spread healthier habits at work

 

“

 

We can’t change a system unless we have a shared understanding and shared language.

—Tristan Harris

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

 

If you work in an environment where people don't respect each other’s use of tech, chances are you are not going to advocate being respectful of the tech habits of your own users.

 

How to act:

Respect people's calendars

Don’t schedule too many meetings in a row, after hours, or during lunchtime; Just because you found a magic spot on their calendar doesn't mean that the person is available.

→

 

Plan your meetings

A meeting shouldn't be a surprise. Make everyone comfortable by communicating your agenda in advance  Share artifacts before the meeting and reserve the first few minutes for colleagues to read them in silence so that everyone is up-to-speed before the discussion starts.

 

→

 

Don't bring your computer to a meeting

If you don't need your computer in the meeting, leaving it at your desk  can help you focus your attention and  make the most of the time with your team. Likewise, avoid checking your phone (or don't even bring it).

 

→

 

Send shorter emails and don't Slack after hours

The easiest it is to send a message, bigger are the chances that people will misuse it. The message goal is not to get it out of your way, but to share it with someone else. Therefore, the receiver side is more important than yours as a sender.

 

→

 

Don't rush to reply or to follow up

If it is that urgent (it rarely is), talking in person might be more effective. Give people time.

→

 

Use whiteboards more often

Whiteboards, pen and paper, and the gold-old post-its can help to visualize what is being discussed, improving alignment, collaboration, and focus.

→

 

Discuss work policies

Discuss with your team which practices you could adjust or implement (e.g. remote work, meeting frequency, feedback channels) in your company to encourage a healthier work-life balance.

 

→

 

Run retrospectives

Retrospective meetings are a great way to check-in with people about how they are feeling regarding workloads and team dynamics. Use this opportunity to check on whether people are implementing healthier tech habits or if they need more guidance or encouragement.

→

 

Lead by example

Design directors and managers: lead by example. If you don’t pull out your phone during a meeting, chances are no one else in the room will either.

 

→

 

In our community

 

Engage beyond panels

 

If design is the rendering of intent, just having the intention is not enough: we need to execute it. How can we engage past our own bubble to make real impact in the world?

→

Reach out to other specialists

While designers hold much of the responsibility for the impact of technology on people's lives, professionals like sociologists, anthropologists, and other researchers who study our relationship with technology hold valuable insights into what we do.

Go beyond your own bubble

The best people to talk to about kids and tech? Parents. The best people to talk to about tech in schools? Students and teachers. Join conversations with people who have a shared interest in this topic, not just a shared background with you.

 

 

 

 

→

Be a team player

We don't hold the answers. Often our role is facilitating rather than solving it. Give support to the specialists and groups that are making a difference.

 

 

 

 

 

 

→

Volunteer your craft

Instead of just talking about it, make your craft available to help non profits (or build side projects) that are making a difference in creating a healthier relationship with technology.

 

 

 

 

 

→

In our personal life

 

Design your own tech diet

 

Look at the world around you: the spaces, objects, and interfaces you interact with on a daily basis. As a designer, you could be thinking about how to best design these things — and how creating the right digital guardrails can have a positive impact on your routine.

 

Understand your own use cases

Asking yourself questions like these will help you identify parts of your day where you could be spending less time or making less decisions:

• How many times through the course of a workday do you reach for a pen and a piece of  paper to sketch something out?

• How do you dress on  the weekdays (when you are in a hurry) vs. on the weekends (when you may have more time, and feel a little more adventurous)?

• What are the three things you need to bring with you every time you leave the house?

 

 

 

→

Defining your personal KPIs

The next step is to define what is important to you. What are you trying to achieve with a simpler or easier life, and why? What are the personal metrics you should design against?

• Less time spent: what are the tasks you repeat every day that can be optimized or automated to save you time? 

• Less forgetting: how can you reduce the number of times you forget things? 

• Less decision-making: how can you reduce the number of decisions you have to make throughout the day?

→

Implement and iterate

Finally, time to take action.

• Turn off badges and notifications on your phone

• Move apps away from your phone home screen and open less important apps by typing

• Charge your phone outside the bedroom

• Find time to go offline for a few hours a day

 

 

→

Designing your life begins with designing the environment around you. Most importantly: share these new behaviors with your family, friends, and people who do not work in tech. As early adopters of technology, we are responsible for  influencing the less nerdy folks around us.

 

Futher reading:

 

The Informed Life →

The Informed Life is an interview-based podcast by Jorge Arango that explores how people from different fields manage their personal information ecosystems to be more effective. 

 

In our personal life

 

Hold other companies accountable

 

 

“

 

It doesn’t matter if our field holds values like respect dear, if we’re not able to get businesses and institutions to adopt those values and apply them to their work.

—Cyd Harrell

 

In the past few years, there has been a bigger mobilization to make companies accountable for bad practices in their workplace and in their products. To mitigate a potential crisis, companies started to make announcements about privacy and well-being, but without actually changing their business practices. As designers, we can take a stand against addictive engagement — and actually do something about it.

 

Report as spam

Any time you receive an unsolicited email or phone call, or are added to a distribution list without permission, use the tools at your disposal to flag this content as inappropriate.

 

Leave honest reviews

Frustrated with an app that is creating anxiety or triggering unhealthy emotions? Leave a comment on the app store so other people can be better informed before deciding to download it.

 

Change your consumption habits

Choose companies whose values align with yours. Choose companies that respect your time and attention. Complaining about a social network but continuing to use it won’t make change happen.

 

Tweet about it

See a dark pattern? Take a screenshot, tweet it, and tag the company. Companies are always tracking mentions to anticipate PR nightmares. This is not about public-shaming other designers, but creating action within that company — while also increasing awareness among  your friends and followers about the products they use.

Dear @Linkedin, why don’t you include the message in the email itself? Do we really need the red notification badge at the top?

It’s not a detox, it’s a re-education

 

Be wary of “digital detoxes”. Similar to our relationship with food, short-term fad diets don’t create long-lasting change but often instill a sense of failure and shame instead.

 

Digital nutrition is about developing and implementing cognitive skills and creating new habits to help us stay in control of our technology consumption.

 

We know that calls for change are easier said than done. The reality of the corporate world is harsh, and leaves very little room for anything that is not driving short-term business results. Designers are in a unique position to spark change, by influencing product decisions, C-level execs and users themselves. To be the change we want to see in the world, we need to start somewhere.
