title: Open Decision Framework
url: https://github.com/red-hat-people-team/open-decision-framework/blob/master/ODF-community.md#open-decision-framework
hash_url: 272e63c4d3672925043c6bfa06f19ed9

Community Version 1.0.4

Updated Apr 10, 2017

© 2014-2017 Red Hat and contributors | The Open Decision Framework was created by the Red Hat People team and is available under Creative Commons Attribution-ShareAlike 4.0 International License ([CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/)). Red Hat and the Shadowman logo are trademarks of Red Hat, Inc. registered in other countries. Modified versions must remove all Red Hat branding.

Notes
=========

* This markdown version of the slides is intended to facilitate easier collaboration and tracking of changes.
* Page numbering corresponds to the LibreOffice (.odp) and PDF files in the repo.

Contents
===========================================================================
* [Overview](#overview)
  * [What is an open decision?](#what-is-an-open-decision)
  * [Open decisions are made using open principles](#open-decisions-are-made-using-open-source-principles)
  * [How open source principles lead to better decisions](#how-open-source-principles-lead-to-better-decisions)
  * [You can't please everyone](#you-cant-please-everyone)
* [Open Decision Framework](#open-decision-framework-1)
  * [Phase or activity: Concept, Define, Ideate](#phase-or-activity-concept-define-ideate)
  * [Phase or activity: Plan, Research](#phase-or-activity-plan-research)
  * [Phase or activity: Design, Develop, Test](#phase-or-activity-design-develop-test)
  * [Phase or activity: Launch, Deploy, Close](#phase-or-activity-launch-deploy-close)
* [Resources](#resources)
* [Appendix](#appendix)
  * [History: Where the framework came from](#history-where-the-open-decision-framework-came-from)
  * [Why the framework exists](#why-the-framework-exists)


Overview
===========================================================================


**What it is**
  - A flexible, open approach to making business decisions and leading projects

**When to use it**

For decisions and projects that are likely to:
  - impact our culture or
  - affect associates beyond your immediate team

**How to use it**
  - Build steps from the Open Decision Framework into your project plan or decision-making process


What is an open decision?
-------------------------


<table>
<tr>
<td>Transparent</td>
<td>Inclusive</td>
<td>Customer-Centric</td>
</tr>
<tr>
<td>Explain who is making the decision, what problems you're trying to solve, the requirements and constraints involved, and the process you will follow.</td>
<td>Engage others for feedback and collaborate throughout the decision-making process. Seek out diverse perspectives, including potential detractors.</td>
<td>Think of people as customers with competing needs and priorities. When a decision will help some customers, but disappoint others, manage relationships and expectations while getting stuff done.</td>
</tr>
</table>


Open decisions are made using open source principles
-----------------------------------------------------


**Open exchange**

Whether you're developing software or trying to solve a business problem, open exchange begins when you share your "source code" with others. A free exchange of ideas is critical to creating an environment where people are allowed to learn and use existing information toward creating new ideas.

**Participation**

When we are free to collaborate, we create. We can solve problems that no one person may be able to solve on their own. And when we can implement open standards, we enable others to participate in the future.

**Release early + often**

Rapid prototypes can lead to rapid failures, and that leads to better solutions faster. When you're free to experiment, you can look at problems in new ways and look for answers in new places. You can learn by doing.

**Meritocracy**

In a meritocracy, good ideas can come from anywhere, and the best ideas win. Everyone has access to the same information. Successful work determines which projects rise and gather support and effort from the community.

**Community**

Communities are formed around a common purpose. They bring together diverse ideas and share work. Together, a global community can create beyond the capabilities of any one individual. It multiplies effort and shares the work. Together, we can do more.

Adapted from: https://opensource.com/open-source-way


How open source principles lead to better decisions
---------------------------------------------------


<table>
<tr>
<td>Principles</td>
<td>→</td>
<td>Practices</td>
<td>→</td>
<td>Outcomes</td>
</tr>
<tr>
<td>
• Open exchange<br/> • Participation<br/> • Release early + often<br/> • Meritocracy<br/> • Community
</td>
<td>→<br/>→<br/>→</td>
<td>
• Transparency with internal customers and other stakeholders<br/> • Customer involvement<br/> • Gain feedback and adapt iterative changes<br/> • Ideation with customers<br/> • Build trust and respect via collaboration
</td>
<td>→<br/>→<br/>→</td>
<td>
• Customer buy-in<br/> • Stronger and faster adoption<br/> • Best ideas win<br/> • Fewer bugs, issues, and unanticipated impacts<br/> • Higher associate engagement<br/> • Decisions aligned to strategy and culture
</td>
</tr>
</table>


You can't please everyone.
----------------------------------------------------
**But when you make open decisions, people feel...**

  - I understand why the decision was made and how it aligns to Red Hat's strategy, goals, and mission.
  - There was visibility to the business requirements, research, and evaluation criteria.
  - The decision-making process was inclusive and transparent.
  - Although I wasn't the decision maker, I was able to contribute to the process.
  - I may not agree with the decision, but it's obvious that the decision makers understand Red Hat's values and culture.
  - I might be disappointed, but I wasn't surprised.
  - My voice was heard and valued.


Open Decision Framework
===========================================================================

Phase or activity: Concept, Define, Ideate
---------------


<table>
<tr>
<td width=34%><strong>Steps you can take to be open</strong></td>
<td width=36%><strong>Questions to ask</strong></td>
<td width=30%><strong>Common flamewar triggers</strong></td>
</tr>
<tr valign="top">
<td rowspan=3>
<strong>Lead with transparency</strong><br/>
 • Publish a problem statement and possible approaches<br/><br/>
 • Identify any aspects of the project or decision that cannot be open<br/><br/>
 • Publish your ideation process<br/><br/>

<strong>Build diversity of thought + an inclusive environment</strong><br/>
 • Engage internal customers and stakeholders early on, especially those who may disagree<br/><br/>
 • Seek out diverse and underrepresented perspectives (geographies, ethnicity, departments, job levels, gender, age, etc.)<br/><br/>
 • Champion collaboration and provide channels for feedback<br/><br/>
 • Address risks, limitations, and potential cultural impacts, especially with historically controversial issues<br/><br/>
</td>
<td>
 • What is the potential impact on the organization? On the culture?<br/><br/>
 • Who do we need to include in planning?<br/><br/>
 • Whose problem are we trying to solve?<br/><Br/>
 • Who will we need or want help from?<br/><br/>
 • Who else could be impacted?<br/><br/>
 • Who has solved a similar problem?<br/><br/>
 • Who is likely to disagree, dissent, reject, or opt out? Who else may care?
</td>
<td rowspan=3>
There are a handful of issues that often generate controversy and upset within Red Hat, including:<br/><br/>
 • Decisions, policies, or changes that impact associates, such as rewards and wellness programs<br/><br/>
 • Changes to associates' work environment<Br/><br/>
 • Implementation of proprietary technology<br/><br/>
 • Use of proprietary formats<Br/><br/>
 • Data privacy and sharing<br/><br/>

If your project or decision involves any of these themes, take extra steps to make your process open, inclusive, and transparent.
</td>
</tr>
<tr>
<td><strong>Key considerations</strong></td>
</tr>
<tr>
<td>
 • Confidentiality, privacy, and regulatory requirements<br/><br/>
 • Potential to generate controversy<br/><br/>
 • Impact on Red Hat's culture and future decisions<br/><br/>
 • Roles + responsibilities (OPT model: https://github.com/red-hat-people-team/opt-model/) <br/><br/>
 • Where to publish
</td>
</tr>
</table>


Phase or activity: Plan, Research
----------------------


<table>
<tr>
<td colspan=2 width="66%"><strong>Steps you can take to be open</strong></td>
<td><strong>Questions to ask</strong></td>
</tr>
<tr valign="top">
<td rowspan=3 width=33%><strong>Engage customers + collaborators</strong><br/>
 • Gather input from internal customers and those who you will need help from (surveys, interviews, focus groups, etc.)<br/><br/>
 • Make it easy to participate + manage. Ask customers which collaboration tools they prefer to use. Have a plan for consolidating and publishing feedback.<br/><br/>
 • Remain open to new information and perspectives<Br/><br/>
 • Consider peer-to-peer feedback and communication options in addition to formal channels<br/><br/>

<strong>Set expectations upfront</strong><Br/>
 • Be specific about what type(s) of feedback you're looking for + who is making the decision(s)<Br/><Br/>
 • Publish decision process and project plan, with roles, dates, constraints
</td>
<td rowspan=3 width=33%><strong>Explain the obvious</strong><Br/>
 • Publish the scope of the project or decision, and reiterate often<br/><br/>
 • Publish decision factors and their relative importance<Br/><Br/>
 • Publish your research, including difficult trade-offs, business requirements<br/><br/>
 • To the extent possible, publish any relevant legal, reporting, or confidentiality concerns<br/><br/>

<strong>Plan the transition</strong><br/><br/>
 • Develop and gather feedback on communication, change management, and adoption plans<br/><Br/>
 • Think through how you could respond to upset individuals (on memo-list and other channels)
</td>
<td>
 • How will we make decisions?<Br/><Br/>
 • What internal customers, stakeholders, and collaborators will we involve?<br/><br/>
 • How will we engage and communicate with them?<br/><br/>
 • What are the open source options?<br/><br/>
 • How might choosing a proprietary technology or format limit our choices in the future?<br/><br/>
 • How does this align with the company strategy and mission?<br/><br/>
 • Where might this conflict with Red Hat's values and culture?
</td>
</tr>
<tr>
<td><strong>Key considerations</strong></td>
</tr>
<tr>
<td>
 • Impact – who, how often, and unexpected<br/>
 • Where and how to collaborate<Br/>
 • Roles + responsibilities (OPT model: https://github.com/red-hat-people-team/opt-model/)
</td>
</tr>
</table>


Phase or activity: Design, Develop, Test
----------------------------


<table>
<tr>
<td colspan=2 width="66%"><strong>Steps you can take to be open</strong></td>
<td><strong>Questions to ask</strong></td>
</tr>
<tr valign="top">
<td rowspan=3 width=33%><strong>Build your community</strong><br/>
 • Ask departments who from their team can provide feedback<Br/><Br/>
 • Socialize decision with customers and stakeholders, especially those that may be more vocal about impacts<br/><br/>
 • Investigate options and accommodations for negatively impacted customers<Br/><Br/>

<strong>Promote open exchange</strong><br/>
 • Evaluate, acknowledge, and incorporate feedback<br/><br/>
 • Highlight changes made in response to feedback<br/><br/>
 • If a suggestion isn't feasible, explain why<br/><br/>
 • Publish progress in an open place<br/><br/>
 • Provide regular updates to sponsors, customers, and stakeholders
</td>
<td rowspan=3 width=33%>
<strong>Make it safe to voice concerns</strong><br/>
 • Invite project team and collaborators to raise risks and concerns you've overlooked.<br/><br/>
 • Ask: What might prevent this project from succeeding? What concerns will your team have? What are we missing?<br/><br/>
 • Publish risk and limitations uncovered along the way<br/><br/>

<strong>Conduct a premortem</strong><br/>
 • Pretend it's launch day, and people are surprised or upset. What triggered it?<br/><br/>
 • Identify changes you would make or points you might clarify in response, and make them proactively instead<br/><br/>

<strong>Activate your ambassadors</strong><Br/>
 • Equip the community to help you clear up misinformation and misunderstandings
</td>
<td>
 • Can we pilot or release early to gather input?<br/><br/>
 • How will we test?<br/><Br/>
 • Which internal customers can help test?<br/><br/>
 • Does a cross-functional working group make sense?<br/><br/>
 • Can we build a community of passion around this project or decision?<br/><br/>
 • Have we engaged the people who will have to do the work?<br/><br/>
 • Who do we need more buy-in or support from?
</td>
</tr>
<tr>
<td><strong>Key considerations</strong></td>
</tr>
<tr>
<td>
 • Representation of different types of customers<br/>
 • Unexpected impacts and use cases<br/>
 • Unspoken risks and concerns
</td>
</tr>
</table>


Phase or activity: Launch, Deploy, Close
--------------


<table>
<tr>
<td colspan=2 width="66%"><strong>Steps you can take to be open</strong></td>
<td><strong>Questions to ask</strong></td>
</tr>
<tr valign="top">
<td rowspan=3 width=33%><strong>Begin with the end in mind</strong><br/>
 • Demonstrate alignment with Red Hat's strategy, mission, culture, and values<br/><br/>
 • Outline the steps you've taken to make this decision openly<br/><br/>
 • Highlight use of this framework<br/><br/>
 • Tell associates where to find detailed information<br/><br/>
 • Show how feedback shaped the decision or project<br/><br/>
 • Explain how to provide input after launch<br/><br/>
 • Acknowledge when you're not fully satisfied with the decision or know that others will not be<br/><br/>
 • Share your timeline or criteria for revisiting the decision<br/><br/>
 • Stay engaged with those who reject the decision
</td>
<td rowspan=3 width=33%>
<strong>Default to open</strong><br/>
 • Reiterate relevant business requirements and constraints<br/><br/>
 • Share relevant legal, reporting, or confidentiality issues<br/><br/>
 • Communicate success criteria and publish relevant metrics<br/><br/>

<strong>Contribute upstream</strong><br/>
 • Publish your methods, lessons learned, communications, and decision criteria to the archive, so others can review past decisions, learn why a decision was made, and see how leaders have responded to similar issues in the past<br/><br/>
 • Offer guidance to others on open decision making and choosing collaboration tools
</td>
<td>
 • How will we monitor mailing lists and other feedback channels after the launch?<br/><br/>
 • If we have done early releases, will we continue to make incremental improvements based on feedback?<br/><br/>
 • How willing are we to make revisions based on feedback?<br/><br/>
 • What's a reasonable window of time for additional input and refinement?<br/><br/>
 • Did we overlook something important? How do we address it?<br/><br/>
 • Does the decision need to be revisited?<br/><br/>
 • Did open decision-making lead to the desired outcomes?<br/><br/>
 • How can we share our lessons learned and encourage open decision-making at Red Hat?
</td>
</tr>
</table>


Resources
===========================================================================


  - [Red Hat Multiplier](https://github.com/red-hat-people-team/red-hat-multiplier) – quick reference sheets on collaboration, transparency, trust, meritocracy, connection
  - [The Open Source Way handbook](https://www.theopensourceway.org/wiki/Introduction) –  guide to creating and nurturing communities of contributors
  - [The Open Organization](http://opensource.com/open-organization) (book + online community)
  - [Prioritizing by impact](http://developerblog.redhat.com/2014/08/27/5-ux-tips-for-developers/), see grid in Máirín Duffy's "5 UX Tips for Developers"
  - [Opensource.com](http://www.opensource.com/) – A Red Hat supported publication focused on how open source principles can be applied to business, education, government, and more
  - [The Advice Process](http://danieltenner.com/2014/11/06/the-advice-process-definition-and-usage-tips/) (Daniel Tenner)


Appendix
===========================================================================

History: Where the Open Decision Framework came from
----------------------------------------------------


  - Based on principles practiced by open source communities

    - Research by Duke University's Fuqua School of Business and Diana Martin (2009 – 2010); additional community resources

  - Developed by the People team, with contributions from cross-functional focus group

    - Grew from People team Project Management Office's effort to create an open project management methodology (2012 – 2013)
    - Google Calendar memo-list conversations served as a catalyst to share drafts with all associates and invite participation (2014)
    - Tested by IT and Engineering, in the Google Calendar bridge working group (2014 – 2015)

  - Updated and maintained by Rebecca Fernandez (rfernand@redhat.com)


Why the framework exists
------------------------


**A collection of proven practices that:**

  - Drive better alignment between business decisions and our company strategy, goals, culture, values, and mission
  - Demonstrate “what good looks like” in decision-making and communication
  - Offer consistent guidance for teams and leaders on Red Hat cultural expectations, balancing transparency and confidentiality
  - Improve associate engagement, signal-to-noise ratio on memo-list
