title: Adactio: Journal-Split
url: https://adactio.com/journal/15050
hash_url: e504bc16c239f638c24d4793d381e1ff

<p>When I talk about <a href="https://adactio.com/articles/12839">evaluating technology</a> for front-end development, I like to draw a distinction between two categories of technology.</p>

<p>On the one hand, you’ve got the raw materials of the web: HTML, CSS, and JavaScript. This is what users will ultimately interact with.</p>

<p>On the other hand, you’ve got all the tools and technologies that help you produce the HTML, CSS, and JavaScript: pre-processors, post-processors, transpilers, bundlers, and other build tools.</p>

<p>Personally, I’m much more interested and excited by the materials than I am by the tools. But I think it’s right and proper that other developers are excited by the tools. A good balance of both is probably the healthiest mix.</p>

<p>I’m never sure what to call these two categories. Maybe the materials are the “external” technologies, because they’re what users will interact with. Whereas all the other technologies—that mosty live on a developer’s machine—are the “internal” technologies.</p>

<p>Another nice phrase is something I heard during <a href="https://adactio.com/journal/14891">Chris’s talk at An Event Apart in Seattle</a>, when he quoted <a href="http://bradfrost.com/">Brad</a>, who talked about <a href="https://adactio.com/journal/14891#Brad%20says">the front of the front end and the back of the front end</a>.</p>

<p>I’m definitely more of a front-of-the-front-end kind of developer. I have opinions on the quality of the materials that get served up to users; the output should be accessible and performant. But I don’t particularly care about the tools that produced those materials on the back of the front end. Use whatever works for you (or whatever works for your team).</p>

<p>As a user-centred developer, my priority is doing what’s best for end users. That’s not to say I don’t value <a href="https://jeremy.codes/blog/defining-productivity/">developer convenience</a>. I do. <a href="https://adactio.com/journal/13333">But I <em>prioritise</em> user needs over developer needs</a>. And in any case, those two needs don’t even come into conflict most of the time. Like I said, from a user’s point of view, it’s irrelevant what text editor or version control system you use.</p>

<p>Now, you could make the argument that anything that is good for developer convenience is automatically good for user experience because faster, more efficient development should result in better output. While that’s true in theory, I highly recommend Alex’s post, <a href="https://infrequently.org/2018/09/the-developer-experience-bait-and-switch/"><cite>The “Developer Experience” Bait-and-Switch</cite></a>.</p>

<p>Where it gets interesting is when a technology that’s designed for developer convenience is made out of the very materials being delivered to users. For example, a CSS framework like Bootstrap is <em>made</em> of CSS. That’s different to a tool like Sass which <em>outputs</em> CSS. Whether or not a developer chooses to use Sass is irrelevant to the user—the final output will be CSS either way. But if a developer chooses to use a CSS framework, that decision has a direct impact on the user experience. The user must download the framework in order for the developer to get the benefit.</p>

<p>So whereas Sass sits at the back of the front end—where I don’t care what you use—Bootstrap sits at the front of the front end. For tools like that, I don’t think saying “use whatever works for you” is good enough. It’s got to be weighed against the cost to the user.</p>

<p>Historically, it’s been a similar story with JavaScript libraries. They’re written in JavaScript, and so they’re going to be executed in the browser. If a developer wanted to use jQuery to make their life easier, the user paid the price in downloading the jQuery library.</p>

<p>But I’ve noticed a welcome change with some of the bigger JavaScript frameworks. Whereas the initial messaging around frameworks like React touted the benefits of state management and the virtual DOM, I feel like that’s not as prevalent now. You’re much more likely to hear people—quite rightly—talk about the benefits of modularity and componentisation. If you combine that with the rise of Node—which means that JavaScript is no longer confined to the browser—then these frameworks can move from the front of the front end to the back of the front end.</p>

<p>We’ve certainly seen that at <a href="https://clearleft.com/">Clearleft</a>. We’ve worked on multiple React projects, but in every case, the output was server-rendered. Developers get the benefit of working with a tool that helps them. Users don’t pay the price.</p>

<p>For me, this question of whether a framework will be used on the client side or the server side is crucial.</p>

<p>Let me tell you about a Clearleft project that sticks in my mind. We were working with a big international client on a product that was going to be rolled out to students and teachers in developing countries. This was right up my alley! We did plenty of research into network conditions and typical device usage. That then informed a tight <a href="https://clearleft.com/posts/responsive-design-on-a-budget">performance budget</a>. Every design decision—from web fonts to images—was informed by that performance budget. We were producing lean, mean markup, CSS, and JavaScript. But we weren’t the ones implementing the final site. That was being done by the client’s offshore software team, and they insisted on using React. “That’s okay”, I thought. “React can be used server-side so we can still output just what’s needed, right?” Alas, no. These developers did everything client side. When the final site launched, the log-in screen alone required megabytes of JavaScript just to render a form. It was, in my opinion, entirely unfit for purpose. It still pains me when I think about it.</p>

<p>That was a few years ago. I think that these days it has become a lot easier to make the decision to use a framework on the back of the front end. Like I said, that’s certainly been the case on recent Clearleft projects that involved React or Vue.</p>

<p>It surprises me, then, when I see the question of server rendering or client rendering treated almost like an implementation detail. It might be an implementation detail from a developer’s perspective, but it’s a key decision for the user experience. The <a href="https://medium.com/@addyosmani/the-cost-of-javascript-in-2018-7d8950fbb5d4">performance cost</a> of putting your entire tech stack into the browser can be enormous.</p>

<p>Alex Sanders from the development team at The Guardian published a post recently called <a href="https://www.theguardian.com/info/2019/apr/04/revisiting-the-rendering-tier"><cite>Revisiting the rendering tier </cite></a>. In it, he describes how they’re moving to React. Now, if this were a move to <em>client</em>-rendered React, that would make a big impact on the user experience. The thing is, I couldn’t tell from the article whether React was going to be used in the browser or on the server. The article talks about “rendering”—which is something that browsers do—and “the DOM”—which is something that only exists in browsers.</p>

<p><a href="https://www.theguardian.com/info/2019/apr/04/revisiting-the-rendering-tier#comment-127743952">So I asked</a>. It turns out that this plan is very much about generating HTML and CSS on the server before sending it to the browser. Excellent!</p>

<p>With that question answered, I’m cool with whatever they choose to use. In this case, they’re choosing to use CSS-in-JS (although, to be pedantic, there’s no C anymore so technically it’s SS-in-JS). As long as the “JS” part is JavaScript <em>on a server</em>, then it makes no difference to the end user, and therefore no difference to me. Not my circus, not my monkeys. For users, the end result is the same whether styling is applied via a selector in an external stylesheet or, for example, via an inline style declaration (and in some situations, a server-rendered CSS-in-JS solution might be <em>better</em> for performance). And so, as a user-centred developer, this is something that I don’t need to care about.</p>

<p>Except…</p>

<p>I have misgivings. But just to be clear, these misgivings have <em>nothing</em> to do with users. My misgivings are entirely to do with another group of people: the people who make websites.</p>

<p>There’s a second-order effect. By making React—or even JavaScript in general—a requirement for styling something on a web page, the barrier to entry is raised.</p>

<p>At least, <em>I</em> think that the barrier to entry is raised. I completely acknowledge that this is a subjective judgement. In fact, the reason why a team might decide to make JavaScript a requirement for participation might well be because they believe it makes it <em>easier</em> for people to participate. Let me explain…</p>

<p>It wasn’t that long ago that devs coming from a Computer Science background were deriding CSS for its simplicity, complaining that “it’s broken” and turning their noses up at it. That rhetoric, thankfully, is waning. Nowadays they’re far more likely to acknowledge that <a href="https://adactio.com/journal/12571">CSS might be simple, but it isn’t easy</a>. Concepts like the cascade and specificity are real head-scratchers, and any prior knowledge from imperative programming languages won’t help you in this declarative world—all your hard-won experience and know-how isn’t fungible. Instead, it seems as though all this cascading and specificity is butchering the modularity of your nicely isolated components.</p>

<p>It’s no surprise that programmers with this kind of background would treat CSS as damage and find ways to route around it. The many flavours of CSS-in-JS are testament to this. From a programmer’s point of view, this solution has made things easier. Best of all, as long as it’s being done on the server, there’s no penalty for end users. But now the price is paid in the diversity of your team. In order to participate, a Computer Science programming mindset is now pretty much a requirement. For someone coming from a more declarative background—with really good HTML and CSS skills—everything suddenly seems needlessly complex. And <a href="https://tantek.com/2018/309/t1/complexity-reinforces-privilege">as Tantek observed</a>:</p>

<blockquote>
  <p>Complexity reinforces privilege.</p>
</blockquote>

<p>The result is a form of gatekeeping. I don’t think it’s intentional. I don’t think it’s malicious. It’s being done with the best of intentions, in pursuit of efficiency and productivity. But these code decisions are reflected in hiring practices that exclude people with different but equally valuable skills and  perspectives.</p>

<p>Rachel describes <a href="https://rachelandrew.co.uk/archives/2019/01/30/html-css-and-our-vanishing-industry-entry-points/">HTML, CSS and our vanishing industry entry points</a>:</p>

<blockquote>
  <p>If we make it so that you have to understand programming to even start, then we take something open and enabling, and place it back in the hands of those who are already privileged.</p>
</blockquote>

<p>I think there’s a comparison here with toxic masculinity. Toxic masculinity is obviously terrible for women, but it’s also really shitty for men in the way it stigmatises any male behaviour that doesn’t fit its worldview. Likewise, if the only people your team is interested in hiring are traditional programmers, then those programmers are going to resent having to spend their time dealing with semantic markup, accessibility, styling, and other disciplines that they never trained in. Heydon correctly identifies this as <a href="http://www.heydonworks.com/article/reluctant-gatekeeping-the-problem-with-full-stack">reluctant gatekeeping</a>:</p>

<blockquote>
  <p>By assuming the role of the Full Stack Developer (which is, in practice, a computer scientist who also writes HTML and CSS), one takes responsibility for all the code, in spite of its radical variance in syntax and purpose, and becomes the gatekeeper of at least some kinds of code <strong>one simply doesn’t care about writing well</strong>.</p>
</blockquote>

<p>This hurts everyone. It’s bad for your team. It’s even worse for the wider development community.</p>

<p>Last year, <a href="https://abookapart.com/blogs/press/get-to-know-jeremy-keith/">I was asked</a> “Is there a fear or professional challenge that keeps you up at night?” I responded:</p>

<blockquote>
  <p>My greatest fear for the web is that it becomes the domain of an elite priesthood of developers. I firmly believe that, as Tim Berners-Lee put it, “this is for everyone.” And I don’t just mean it’s for everyone to use—I believe it’s for everyone to make as well. That’s why I get very worried by anything that raises the barrier to entry to web design and web development.</p>
</blockquote>

<p>I’ve described a number of dichotomies here:</p>

<ul>
<li>Materials vs. tools,</li>
<li>Front of the front end vs. back of the front end,</li>
<li>User experience vs. developer experience,</li>
<li>Client-side rendering vs. server-side rendering,</li>
<li>Declarative languages vs. imperative languages.</li>
</ul>

<p>But the split that worries the most is this:</p>

<ul>
<li>The people who make the web vs. the people who are excluded from making the web.</li>
</ul>
