title: Thinking vs Choosing
url: https://www.the-haystack.com/2019/09/20/thinking-vs-choosing/
hash_url: 656cf1cb60d35d056c844d0364bc715d

<p><em>This is the first of two articles about critical thinking in design. In part one, I discuss why I feel there’s so much “design sameness” on the web, and the drawbacks of our tendency to focus on existing solutions. In the upcoming Part 2, I’ll present a model that I’ve found useful in making more context-appropriate design decisions. My thinking and research on this topic also resulted in a recent conference talk: “<a href="https://beyondtellerrand.com/events/dusseldorf-2019/speakers/stephen-hay">I Don’t Care What Airbnb is Doing (and Neither Should You)</a>”.</em></p>
<hr/>
<p>Those who have spent any significant amount of time working in design—or most other creative fields—become aware of an ocean of prior solutions to various creative problems. I don’t mean frameworks for developing creativity, ideation exercises, or lessons on how to get out of one’s own way and allow creative insight to appear. These are aids to thinking. I mean existing solutions executed by others at some point in time, for any particular type of project. The massive repository of existing work that’s easily found by a keyword search in your web browser. Portfolios. Showcases. These are aids to doing. Or copying. There seems to be a tendency to repurpose existing solutions to other people’s problems. I propose that this is the main cause of the design sameness that we encounter on the web (and in apps) today. In our (un)conscious attempts to reduce the effort needed to do our work, <em>we’ve become experts in choosing rather than in thinking</em>.</p>
<h2>But, conventions</h2>
<p>We rely on conventions because they often provide us with a working solution via a minimum of effort. This may be our natural tendency; Daniel Kahneman has written that the brain is “a machine for jumping to conclusions.” While this may be true, it’s this very same thinking that we criticize in those outside of our designer role when they voice their opinion. When they ask, “hey, can we do something like our competitor does?”, we might cringe accordingly. Since when is imitating a competitor a solid differentiation strategy? Yet the moment that person goes away and we’re in need of a solution, we’re knee-deep in some UI pattern library or Google image search.</p>
<p>But we don’t always copy outright. We <em>remix</em>. We think tailoring an existing solution to our own problem constitutes a creative solution. (It might, but not always.) Worse, we tell ourselves stories. We justify our choices by conflating ubiquity with appropriateness. The fact that many people do the same thing doesn’t always mean what we think it does. It could just mean that lots of people copy what other people do. We seldom really know. Many designers talk about using “social proof” to influence customers, yet we allow that same principle to influence our design choices. The more we see something out there, the better it must be.</p>
<p>We owe it to ourselves, our customers, and each other, to think critically. To carefully examine and be honest about why we make the “creative” choices we do.</p>
<p>Behavioral economist David Hirshleifer describes this phenomenon in his 1997 paper <em>Informational Cascades and Social Conventions</em>:</p>
<blockquote><p>With many individuals, with virtual certainty a point is reached where an individual rationally ignores his private information and bases his decision solely upon what he sees predecessors do. The accumulated evidence from predecessors outweighs his private information. The decision of this individual n is uninformative to later choosers. Thus, individual n+1 is no better informed than individual n, so she joins the cascade.</p></blockquote>
<p>When discussing this with designers, I often get a response like, “So what? What’s wrong with using proven conventions?” Very recently, a designer told me that they’d like to see <em>more</em> designers looking at what other companies are doing, rather than coming up with their own unproven ideas. I tried to reassure them that they needn’t worry: there’s no shortage of designers looking at existing solutions. The entire web serves as sufficient evidence of this. And it’s nothing new. Early in my career, when I worked in print design, most designers I knew would reach for their collection of design annuals—collections of design work done in a given year—to “get inspired” when starting a new project.</p>
<h2>The basis for our decisions</h2>
<p>When we use existing solutions or patterns, we use a different kind of thinking. Our focus is on finding which pattern will work for us. Too quickly, we turn our attention away from closely examining the problem. Deeply understanding a problem, ignoring the solutions of others (or generic solutions) <em>at first</em>, and ideating one’s own solutions becomes a process of <em>learning</em>. You learn <em>why</em> something will or won’t work. Simply applying a known pattern because “users know these conventions” involves no increase in your knowledge. You’ve narrowed the landscape of possible solutions to those <em>others</em> have devised. By extension, you will never be one of those “others”.</p>
<p>Sure, you just need to get the job done. Being a forerunner is not required. Learning is not our goal. While this may be true, and while many existing solutions may work perfectly for your situation, there’s a more insidious aspect to working this way. As Bent Flyvbjerg states:</p>
<blockquote><p>(An) exclusive use of analytical rationality tends to impede further improvement in human performance because of analytical rationality’s slow reasoning and its emphasis on rules, principles, and universal solutions. Second, bodily involvement, speed, and an intimate knowledge of concrete cases in the form of good examples is a prerequisite for true expertise.</p></blockquote>
<p>I often use the example of A/B testing. When testing A against B, the results come from the specific comparison. B might be the best solution, but we only know anything at all about B <em>as it is compared to A</em>. B then becomes the new A, and subsequent choices are derived from that. Perhaps a better visualization is that of a fork in the road. The roads available to you in the future depend on the choice you make now. How are you making that choice? Based on existing work on similar problems, or based on a deep understanding of your own?</p>
<h2>Design is hard</h2>
<p>The <em>hard</em> part of design is the thinking. When we try to eliminate thinking through imitation, we rely on the thinking of others, and attempt to apply their thinking to our problem. Not only have you effectively outsourced the valuable part of design, but it might not be the best solution for your project.</p>
<p>From Bent Flyvbjerg’s collection of misunderstandings in case-study research:</p>
<blockquote><p>Misunderstanding no. 1: General, theoretical (context independent) knowledge is more valuable than concrete, practical (context dependent) knowledge.</p></blockquote>
<p>The above quote yields a glimpse into my position on the entire matter: <em>stop focusing on the solution, and start focusing on the problem</em>. You probably know more about your specific problem than the people behind your “found” solutions do. It’s a reasonable approach to give this knowledge precedence over the unknown data that influenced the design decisions of others.</p>
<p>We often consider something “creative” due to some unexpected juxtaposition of elements. The elements themselves are rarely new or otherwise special. A deep focus on our specific problem and our context-specific knowledge around it can lead to such “creative” solutions, and is a solid start toward creating appropriate design. It might not be what everyone else is doing.</p>
